% IFPEN: 2013/05/15
% Spectral analysis of a series of ultrasound burst signals
% Display basic max. spectrum parameters
% Uses FFTR.m, available on the webpage

% Change the path wrt the location of files
addpath('D:\User_Personal\Laurent_Personnel_Confidentiel\Site_laurent-duval-lcd-siva\_WWW_Hidden\Documents-Supelec-FI\');
load('Supelec_2012_SIR_Spectral_Analysis_EA_v002');

% Desribes the info contained in variable data_Info
% data_Info(1,:) contains the channel ID (1, 2, 3, 4), ie a sensor number
% the set of data_Mat(:,i_Signal) such that their data_Info(1,i_Signal) are
% equal should be considered as recorded from the same sensor

% data_Info(2,:) contains, with respect to the channel ID (1, 2, 3, 4), the
% rank of the unitary signal. In other words, among signals with the same channel ID 
% the signal with data_Info(2,:) = 1 is the first in the series from the
% same sensor, the signal with data_Info(2,:) = 2 is the second

% The homework consists, in groups of 2-3, in:
% 1) proposing one or several spectral estimators for each signal related to each sensor
% 2) representing the evolution of these spectral estimators over time, ie wrt data_Info(2,:)
% 3) validating the proposition wrt to the robustness to noise.

time_Sampling = 1e-6; 

[n_Sample,n_Signal] = size(data_Mat);
max_Loc = zeros(1,n_Signal);
max_Amp = zeros(1,n_Signal);
% for i_Signal = 1:n_Signal
for i_Signal = 1:n_Signal
  [fftR,fftAxe] = FFTR(data_Mat(:,i_Signal)-mean(data_Mat(:,i_Signal) ),time_Sampling);
  [m_Amp,m_Loc] = max(fftR);
  f_Loc = fftAxe(m_Loc);
  max_Amp(1,i_Signal) = m_Amp; % returns the maximum amplitude on the amplitude spectrum
  max_Loc(1,i_Signal) = f_Loc; % returns the frequency at maximum amplitude on the amplitude spectrum
end
figure(1)
title('Max. spectrum amplitude and frequency over time')
subplot(2,1,1)
plot(max_Loc)
xlabel('Sig. index');
ylabel('Max. amp. (u.a)');
subplot(2,1,2)
plot(max_Amp)
ylabel('Max. freq. (Hz)');
xlabel('Sig. index');

figure(2);clf
title('Max. spectrum amplitude vs frequency')
plot(max_Loc,max_Amp,'.')
xlabel('Max. freq. (Hz)');
ylabel('Max. amp. (u.a)');
grid on

figure(3)
title('Max. spectrum amplitude and frequency over time')
plot3(1:n_Signal,max_Loc,max_Amp,'.')
xlabel('Sig. index');
ylabel('Max. freq. (Hz)');
zlabel('Max. amp. (u.a)');
view(-74,42)
grid on
