% IFPEN: 2013/05/15
% Spectral analysis of a series of ultrasound burst signals
% Proposes other center frequency estimators
% Uses FFTR.m, available on the webpage
% WORK: extend to all signals, compare estimators for classification with
% respect to additive noise

% Change the path wrt the location of files
addpath('D:\User_Personal\Laurent_Personnel_Confidentiel\Site_laurent-duval-lcd-siva\_WWW_Hidden\Documents-Supelec-FI\');
load('Supelec_2012_SIR_Spectral_Analysis_EA_v002');

% Define low-cut, high-cut filter parameters (adapted to this signal, maybe not suitable for  other signals)
f_Low = 0.8e4;f_High = 20e4;
[B_cut,A_cut] = cheby2(2,40,[f_Low f_High]*2/freq_Sampling);

% Test with only zero-level noise
lst_Noise_Level = [0];
% Test with different additional zero-level noise
lst_Noise_Level = [0,1,2,4,8, 16, 32]*5e-4;

% Set basic signal parameters
time_Sampling = 0.0000010000;
freq_Sampling = 1/time_Sampling;
% Choose one specific signal and set time axis
index_Data_Demo = 150;
data_Demo = data_Mat(:,index_Data_Demo);
data_Length = length(data_Demo);
data_Demo_Time_Axis = time_Sampling*([1:data_Length]-1)';

% Definie apodizing window parameters
time_Burst_Max = 0.6e-3;
taper_Burst_Length = 20;
taper_Fractional_Order = 2;
sample_Burst_Max = max(find(data_Demo_Time_Axis <= time_Burst_Max))-1;


  for i_Noise_Level  = 1:length(lst_Noise_Level)
    data_Demo_N = data_Demo + lst_Noise_Level(i_Noise_Level)*randn(size(data_Demo));
    
    % Window the signal and fill with zeros
    data_Demo_Window = data_Demo_N.*...
      [Window_Raised_Frac_Sine(sample_Burst_Max,taper_Burst_Length,taper_Fractional_Order);zeros(data_Length-sample_Burst_Max,1)];
    
    % Define low-cut, high-cut filter parameters (adapted to this signal, maybe not to other signals)
    data_Demo_Filt = filtfilt(B_cut,A_cut,data_Demo_Window);
    
    % Here we have a three signal matrix: data, data windowed, data windowed
    % and filtered, to compare spectra, parameters, etc.
    data_Demo_Matrix = [data_Demo_N,data_Demo_Window,data_Demo_Filt];
    
    % Estimate a kind of "noise signal"
    data_Noise = data_Demo_N-data_Demo_Filt;
    [data_Noise_Median,data_Noise_Med] = MAD_Estimate(data_Noise - mean(data_Noise),1);
    
    % Compute the spectra
    [data_Demo_FFT,data_Demo_FFT_Axis] = FFTR(data_Demo_Matrix,time_Sampling);
    
    % Compute three max location (in frequency) add max amplitude
    [data_Demo_FFT_Max,data_Demo_FFT_Idx] = max(data_Demo_FFT);
    % Compute two additional "centroid"/center of mass-like locations, based on
    % abs. value of the spectrum, or squared value of the spectrum
    data_Demo_Filt_Centroid1 = sum(data_Demo_FFT_Axis.*(abs(data_Demo_FFT(:,3))).^1)/sum((abs(data_Demo_FFT(:,3))).^1);
    data_Demo_Filt_Centroid2 = sum(data_Demo_FFT_Axis.*(abs(data_Demo_FFT(:,3))).^2)/sum((abs(data_Demo_FFT(:,3))).^2);
    
    % Here we have 5 "frequency" locations defined from one signal
    data_Central_Location = [data_Demo_FFT_Axis(data_Demo_FFT_Idx);data_Demo_Filt_Centroid1;data_Demo_Filt_Centroid2];
    
    data_Demo_Filt_Cent_Value1 = (mean((abs(data_Demo_FFT(:,3))).^1));
    data_Demo_Filt_Cent_Value2 = sqrt(mean((abs(data_Demo_FFT(:,3))).^2));
    
    % Here we have 5 "amplitude" related to the 5 locations defined from one signal
    data_Central_Value = [data_Demo_FFT_Max';data_Demo_Filt_Cent_Value1;data_Demo_Filt_Cent_Value2];
    
    % Plot results
    figure(i_Noise_Level);clf
    subplot(2,1,1);hold on
    plot(data_Demo_Time_Axis,data_Demo_Matrix);axis tight;grid
    plot(data_Demo_Time_Axis,data_Noise_Med,'b');axis tight;grid
    plot(data_Demo_Time_Axis,-data_Noise_Med,'b');axis tight;grid
    ylabel('Amplitude (au)');
    xlabel('Time (s)');
    legend('Signal','Signal windowed','Signal filtered')
    subplot(2,1,2);hold on
    plot(data_Demo_FFT_Axis,data_Demo_FFT);axis tight;grid
    ylabel('Amplitude (au)');
    xlabel('Frequency (Hz)');
    legend('Signal','Signal windowed','Signal filtered')
    % Plot the location of the five spectrum locations
    h = plot(data_Central_Location,data_Central_Value,'xk');set(h,'LineWidth',10);
  end
  
